Asynchronous Instagram Private API wrapper.

Use the most recent version of the API from Instagram.

Features:

Performs Public API (web, anonymous) or Private API (mobile app, authorized) requests depending on the situation (to avoid Instagram limits)
Challenge Resolver have Email (as well as recipes for automating receive a code from email) and SMS handlers
Support upload a Photo, Video, IGTV, Clips (Reels), Albums and Stories
Support work with User, Media, Insights, Collections, Location (Place), Hashtag and Direct objects
Like, Follow, Edit account (Bio) and much more else
Insights by account, posts and stories
Build stories with custom background, font animation, swipe up link and mention users